@@ -1,7 +1,7 @@
 package Pod::Weaver::Section::Completion::GetoptLongComplete;
 
-our $DATE = '2014-11-23'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2014-11-29'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -68,6 +68,17 @@ can just run C<bash-completion-prog> and the C<complete> command will be added
 to your C<~/.bash-completion-prog>. Your next shell session will then recognize
 tab completion for the command.
 
+$h2 fish
+
+To activate fish completion for this script, execute:
+
+ begin; set -lx COMP_SHELL fish; set -lx COMP_MODE gen_command; $command_name; end > \$HOME/.config/fish/completions/$command_name.fish
+
+Or if you want to install globally, you can instead write the generated script
+to C</etc/fish/completions/$command_name.fish> or
+C</usr/share/fish/completions/$command_name.fish>. The exact path might be
+different on your system. Please check your C<fish_complete_path> variable.
+
 $h2 tcsh
 
 To activate tcsh completion for this script, put:
@@ -82,7 +93,7 @@ $h2 zsh
 
 To activate zsh completion for this script, put:
 
- $func_name() { read -l; local cl="\$REPLY"; read -ln; local cp="\$REPLY"; reply=(`COMP_LINE="\$cl" COMP_POINT="\$cp" $command_name`) }
+ $func_name() { read -l; local cl="\$REPLY"; read -ln; local cp="\$REPLY"; reply=(`COMP_SHELL=zsh COMP_LINE="\$cl" COMP_POINT="\$cp" $command_name`) }
 
  compctl -K $func_name $command_name
 
@@ -119,7 +130,7 @@ Pod::Weaver::Section::Completion::GetoptLongComplete - Add a COMPLETION section
 
 =head1 VERSION
 
-This document describes version 0.03 of Pod::Weaver::Section::Completion::GetoptLongComplete (from Perl distribution Pod-Weaver-Section-Completion-GetoptLongComplete), released on 2014-11-23.
+This document describes version 0.04 of Pod::Weaver::Section::Completion::GetoptLongComplete (from Perl distribution Pod-Weaver-Section-Completion-GetoptLongComplete), released on 2014-11-29.
 
 =head1 SYNOPSIS
 
